summaryrefslogtreecommitdiff
path: root/mali_kbase/mali_kbase_js_policy_cfs.c
diff options
context:
space:
mode:
Diffstat (limited to 'mali_kbase/mali_kbase_js_policy_cfs.c')
-rw-r--r--mali_kbase/mali_kbase_js_policy_cfs.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/mali_kbase/mali_kbase_js_policy_cfs.c b/mali_kbase/mali_kbase_js_policy_cfs.c
index 90c1345..1ac0569 100644
--- a/mali_kbase/mali_kbase_js_policy_cfs.c
+++ b/mali_kbase/mali_kbase_js_policy_cfs.c
@@ -149,9 +149,9 @@ static inline int kbasep_js_policy_trace_get_refcnt(struct kbase_device *kbdev,
js_devdata = &kbdev->js_data;
- spin_lock_irqsave(&js_devdata->runpool_irq.lock, flags);
+ spin_lock_irqsave(&kbdev->hwaccess_lock, flags);
refcnt = kbasep_js_policy_trace_get_refcnt_nolock(kbdev, kctx);
- spin_unlock_irqrestore(&js_devdata->runpool_irq.lock, flags);
+ spin_unlock_irqrestore(&kbdev->hwaccess_lock, flags);
return refcnt;
}
@@ -223,7 +223,7 @@ int kbasep_js_policy_init_ctx(struct kbase_device *kbdev, struct kbase_context *
* head_runtime_us occur strictly after this context is initialized */
mutex_lock(&js_devdata->queue_mutex);
/* No need to hold the the runpool_irq.lock here, because we're initializing
* the value, and the context is definitely not being updated in the
* runpool at this point. The queue_mutex ensures the memory barrier. */
ctx_info->runtime_us = policy_info->head_runtime_us + priority_weight(ctx_info, (u64) js_devdata->cfs_ctx_runtime_init_slices * (u64) (js_devdata->ctx_timeslice_ns / 1000u));
@@ -223,7 +223,7 @@ int kbasep_js_policy_init_ctx(struct kbase_device *kbdev, struct kbase_context *
* head_runtime_us occur strictly after this context is initialized */
mutex_lock(&js_devdata->queue_mutex);
- /* No need to hold the the runpool_irq.lock here, because we're initializing
+ /* No need to hold the the hwaccess_lock here, because we're initializing
* the value, and the context is definitely not being updated in the
* runpool at this point. The queue_mutex ensures the memory barrier. */